==> v8.3.zip: ru_twords_ru_tw/bible/other/courtyard.md <==
# двор

## Определение:

Двор — это территория, огороженная какими-либо постройками. Двор может быть внутренним или внешним.

* Скиния находилась во внутреннем дворе, окруженном толстыми завесами.
* В иерусалимском храме было три внутренних двора: первый — для священников, второй — для иудейских мужчин, третий — для иудейских женщин.
* Внутренние дворы храма были отделены от внешнего низкой каменной стеной. На территории внешнего двора могли находиться язычники.
* Дворы, находившиеся вблизи домов, обычно представляли собой открытый, ничем не огороженный участок.
* Выражение “дворы Господа” часто используется в переносном значении, когда речь идёт о месте пребывания Бога, куда приходят люди, чтобы Его почтить.
* “Царским двором” может называться дворец, а также отдельная его часть, где правитель принимает судебные решения.

## Варианты перевода:

* Словосочетание “внутренний двор” можно перевести как “огороженный участок”, “территория, огороженная стеной”, “территория храма”.
* В некоторых случаях слово “храм” нужно заменять словосочетанием “внутренние дворы храма” — чтобы было ясно, что речь идёт не о здании храма, а о его дворах.
* Выражение “дворы Господа” можно перевести как “место, где пребывает Господь” или “место, где люди поклоняются Богу”.

(См. также: [язычник](../kt/gentile.md), [судья](../other/judgeposition.md), [царь](../other/king.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [4 Цар. 20:4-5](rc://*/tn/help/2ki/20/04)
* [Исх. 27:9-10](rc://*/tn/help/exo/27/09)
* [Иер. 19:14-15](rc://*/tn/help/jer/19/14)
* [Лк. 22:54-55](rc://*/tn/help/luk/22/54)
* [Мф. 26:69-70](rc://*/tn/help/mat/26/69)
* [Чис. 3:24-26](rc://*/tn/help/num/03/24)
* [Пс. 65:4](rc://*/tn/help/psa/065/004)

## Данные о слове:

* Номера Стронга: H1004, H1508, H2691, H5835, H6503, H7339, H8651, G833, G933, G2681, G4259

==> v9.2.zip: ru_twords_ru_tw/bible/other/courtyard.md <==
# двор

## Определение:

Двор — это территория, огороженная какими-либо постройками. Двор может быть внутренним или внешним. 

* Скиния находилась во внутреннем дворе, окруженном толстыми завесами. 
* В иерусалимском храме было три внутренних двора: первый — для священников, второй — для иудейских мужчин, третий — для иудейских женщин.
* Внутренние дворы храма были отделены от внешнего низкой каменной стеной. На территории внешнего двора могли находиться язычники.  
* Дворы, находившиеся вблизи домов, обычно представляли собой открытый, ничем не огороженный участок. 
* Выражение “дворы Господа” часто используется в переносном значении, когда речь идёт о месте пребывания Бога, куда приходят люди, чтобы Его почтить. 
* “Царским двором” может называться дворец, а также отдельная его часть, где правитель принимает судебные решения. 

## Варианты перевода: ## 
 
* Словосочетание “внутренний двор” можно перевести как “огороженный участок”, “территория, огороженная стеной”, “территория храма”.
* В некоторых случаях слово “храм” нужно заменять словосочетанием “внутренние дворы храма” — чтобы было ясно, что речь идёт не о здании храма, а о его дворах.
* Выражение “дворы Господа” можно перевести как “место, где пребывает Господь” или “место, где люди поклоняются Богу”.

(См. также: [язычник](../kt/gentile.md), [судья](../other/judgeposition.md), [царь](../other/king.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [4 Цар. 20:4-5](rc://ru/tn/help/2ki/20/04)
* [Исх. 27:9-10](rc://ru/tn/help/exo/27/09)
* [Иер. 19:14-15](rc://ru/tn/help/jer/19/14)
* [Лк. 22:54-55](rc://ru/tn/help/luk/22/54)
* [Мф. 26:69-70](rc://ru/tn/help/mat/26/69)
* [Чис. 3:24-26](rc://ru/tn/help/num/03/24)
* [Пс. 65:4](rc://ru/tn/help/psa/065/004)

## Данные о слове:

* Номера Стронга: H1004, H1508, H2691, H5835, H6503, H7339, H8651, G833, G933, G2681, G4259
